@@ -125,7 +125,9 @@ def read_star_filament_file(path, box_width, min_distance=0):
                 parts = int((length / (0.1 * box_width)))
             else:
                 parts = length / min_distance
-            boxes = utils.getEquidistantBoxes(box1=box_start, box2=box_end, num_boxes=parts)
+            boxes = utils.getEquidistantBoxes(
+                box1=box_start, box2=box_end, num_boxes=parts
+            )
             f = Filament(boxes)
             filaments.append(f)
 
@@ -167,13 +169,17 @@ def read_eman1_boxfile(path):
     :return: List of bounding boxes
     """
     boxreader = np.atleast_2d(np.genfromtxt(path))
-    boxes = []
-    for box in boxreader:
-        bound_box = BoundBox(x=box[0], y=box[1], w=box[2], h=box[3])
-        boxes.append(bound_box)
+    boxes = [BoundBox(x=box[0], y=box[1], w=box[2], h=box[3]) for box in boxreader]
     return boxes
 
 
+def _create_cbox_boundbox(box):
+    bound_box = BoundBox(x=box[0], y=box[1], w=box[2], h=box[3], c=box[4])
+    if len(box) > 5:
+        bound_box.meta["est_box_size"] = (box[5], box[6])
+    return bound_box
+
+
 def read_cbox_boxfile(path):
     """
     Read a box file in EMAN1 box format.
@@ -181,10 +187,8 @@ def read_cbox_boxfile(path):
     :return: List of bounding boxes
     """
     boxreader = np.atleast_2d(np.genfromtxt(path))
-    boxes = []
-    for box in boxreader:
-        bound_box = BoundBox(x=box[0], y=box[1], w=box[2], h=box[3], c=box[4])
-        boxes.append(bound_box)
+
+    boxes = [_create_cbox_boundbox(box) for box in boxreader]
     return boxes
 
 
@@ -206,8 +210,12 @@ def write_cbox_file(path, boxes):
         )
 
         for box in boxes:
+            est_width = box.meta["boxsize_estimated"][0]
+            est_height = box.meta["boxsize_estimated"][1]
             # box.x / box.y = Lower left corner
-            boxwriter.writerow([box.x, box.y, box.w, box.h, box.c])
+            boxwriter.writerow(
+                [box.x, box.y, box.w, box.h, box.c, est_width, est_height]
+            )
 
 
 def write_boxfile_manager(path, rectangles):
@@ -302,7 +310,9 @@ def read_eman1_filament_start_end(path, min_distance=0):
                 parts = int((length / (0.1 * box_width)))
             else:
                 parts = length / min_distance
-            boxes = utils.getEquidistantBoxes(box1=box_start, box2=box_end, num_boxes=parts)
+            boxes = utils.getEquidistantBoxes(
+                box1=box_start, box2=box_end, num_boxes=parts
+            )
             f = Filament(boxes)
             filaments.append(f)
 
@@ -319,6 +329,12 @@ def is_eman1_helicon(path):
 
 
 def read_eman1_helicon(path, min_distance=0):
+    """
+
+    :param path: Path to boxfiel in helicon formats
+    :param min_distance: Two boxes in the filament will have at least this distance
+    :return:
+    """
 
     if os.stat(path).st_size != 0:
         split_indicis = []
@@ -381,24 +397,30 @@ def write_eman1_helicon(filaments, path, image_filename):
             boxwriter.writerow(["#segment width: " + str(int(boxsize))])
 
             for fil in filaments:
-                boxwriter.writerow(
-                    [
-                        "#helix: ("
-                        + str(fil.boxes[0].x + boxsize / 2)
-                        + ", "
-                        + str(fil.boxes[0].y + boxsize / 2)
-                        + "),"
-                        + "("
-                        + str(fil.boxes[len(fil.boxes) - 1].x + boxsize / 2)
-                        + ", "
-                        + str(fil.boxes[len(fil.boxes) - 1].y + boxsize / 2)
-                        + "),"
-                        + str(int(boxsize))
-                    ]
-                )
-
-                # helix: (3597.3, 2470.9),(3110.9, 3091.7000000000003),38
-                for box in fil.boxes:
+                if len(fil.boxes) > 0:
                     boxwriter.writerow(
-                        ["" + str(box.x + boxsize / 2) + " " + str(box.y + boxsize / 2)]
+                        [
+                            "#helix: ("
+                            + str(fil.boxes[0].x + boxsize / 2)
+                            + ", "
+                            + str(fil.boxes[0].y + boxsize / 2)
+                            + "),"
+                            + "("
+                            + str(fil.boxes[len(fil.boxes) - 1].x + boxsize / 2)
+                            + ", "
+                            + str(fil.boxes[len(fil.boxes) - 1].y + boxsize / 2)
+                            + "),"
+                            + str(int(boxsize))
+                        ]
                     )
+
+                    # helix: (3597.3, 2470.9),(3110.9, 3091.7000000000003),38
+                    for box in fil.boxes:
+                        boxwriter.writerow(
+                            [
+                                ""
+                                + str(box.x + boxsize / 2)
+                                + " "
+                                + str(box.y + boxsize / 2)
+                            ]
+                        )
