@@ -37,7 +37,7 @@ import cryolo.lowpass as lowpass
 import cryolo.preprocessing as preprocess
 from . import utils
 from gooey import Gooey, GooeyParser
-
+from distutils import util as distutils
 
 os.environ["CUDA_DEVICE_ORDER"] = "PCI_BUS_ID"
 try:
@@ -46,6 +46,15 @@ except KeyError:
     os.environ["CUDA_VISIBLE_DEVICES"] = "0"
 os.environ["HDF5_USE_FILE_LOCKING"] = "FALSE"
 
+try:
+    os.environ["CUDA_VISIBLE_DEVICES"]
+except KeyError:
+    os.environ["CUDA_VISIBLE_DEVICES"] = "0"
+
+try:
+    os.environ["CRYOLO_USE_MULTITHREADING"]
+except KeyError:
+    os.environ["CRYOLO_USE_MULTITHREADING"] = "FALSE"
 
 def create_parser(parser):
     """
@@ -176,7 +185,7 @@ def create_parser(parser):
     deexsp_group.add_argument(
         "--use_multithreading",
         action="store_true",
-        default=False,
+        default=distutils.strtobool(os.environ["CRYOLO_USE_MULTITHREADING"]),
         help="If python multiprocessing leads to problems during training (e.g. freezing, dying workers) use multithreading instead of multiprocessing.",
     )
 
@@ -292,6 +301,7 @@ def _main_():
 
     # r'^\d+ particles are found in .* \( (\d+) % \)$'
     kwargs = {"terminal_font_family": "monospace", "richtext_controls": True}
+
     Gooey(
         main,
         program_name="crYOLO train",
@@ -303,6 +313,8 @@ def _main_():
     )()
 
 
+
+
 def main(args=None):
     """
     Main function. Read the arguments, start the program :-)
@@ -687,6 +699,7 @@ def main(args=None):
         from keras.utils import multi_gpu_model
 
         parallel_model = multi_gpu_model(yolo.model, gpus=num_gpus, cpu_merge=False)
+        config["train"]["batch_size"] = config["train"]["batch_size"]*num_gpus
     try:
         tf_log_path = os.path.join(log_path, "tensorflow/")
         if not os.path.exists(tf_log_path):
@@ -727,8 +740,11 @@ def main(args=None):
 
     end = time.time()
 
-    print("Time elapsed for training:", (end - start))
+    # We need to do this, otherwise we get an exception at the end of the training...
+    for p in multiprocessing.active_children():
+        p.terminate()
 
+    print("Time elapsed for training:", (end - start))
     if args.cleanup:
         print("#########################")
         print("Delete filtered images...")
@@ -739,6 +755,7 @@ def main(args=None):
         print("#########################")
 
 
+
 if __name__ == "__main__":
     start_method = "spawn"
     try:
@@ -748,5 +765,9 @@ if __name__ == "__main__":
             start_method = os_start_method
     except:
         pass
+
     multiprocessing.set_start_method(start_method)
+
     _main_()
+
+
